@@ -1,9 +1,9 @@
 # File	  : Zlib.pm
 # Author  : Paul Marquess
 # Created : 8th July 1996
-# Version : 1.01
+# Version : 1.02
 #
-#     Copyright (c) 1995, 1996, 1997 Paul Marquess. All rights reserved.
+#     Copyright (c) 1995-1999 Paul Marquess. All rights reserved.
 #     This program is free software; you can redistribute it and/or
 #     modify it under the same terms as Perl itself.
 #
@@ -70,7 +70,7 @@ use vars qw($VERSION @ISA @EXPORT $AUTOLOAD
 );
 
 
-$VERSION = "1.01" ;
+$VERSION = "1.02" ;
 
 
 sub AUTOLOAD {
@@ -324,10 +324,10 @@ Compress::Zlib - Interface to zlib compression library
     $dest = compress($source) ;
     $dest = uncompress($source) ;
 
-    $gz = gzopen($filename or filenamdle, $mode) ;
-    $status = $gz->gzread($buffer [,$size]) ;
-    $status = $gz->gzreadline($line) ;
-    $status = $gz->gzwrite($buffer) ;
+    $gz = gzopen($filename or filehandle, $mode) ;
+    $bytesread = $gz->gzread($buffer [,$size]) ;
+    $bytesread = $gz->gzreadline($line) ;
+    $byteswritten = $gz->gzwrite($buffer) ;
     $status = $gz->gzflush($flush) ;
     $status = $gz->gzclose() ;
     $errstring = $gz->gzerror() ; 
@@ -672,15 +672,21 @@ If a reference to an open filehandle is passed in place of the
 filename, gzdopen will be called behind the scenes. The third example
 at the end of this section, I<gzstream>, uses this feature.
 
-=item B<$status = $gz-E<gt>gzread($buffer [, $size]) ;>
+=item B<$bytesread = $gz-E<gt>gzread($buffer [, $size]) ;>
 
 Reads B<$size> bytes from the compressed file into B<$buffer>. If
 B<$size> is not specified, it will default to 4096. If the scalar
 B<$buffer> is not large enough, it will be extended automatically.
 
-=item B<$status = $gz-E<gt>gzreadline($line) ;>
+Returns the number of bytes actually read. On EOF it returns 0 and in
+the case of an error, -1.
 
-Reads the next line from the compressed file into B<$line>.
+=item B<$bytesread = $gz-E<gt>gzreadline($line) ;>
+
+Reads the next line from the compressed file into B<$line>. 
+
+Returns the number of bytes actually read. On EOF it returns 0 and in
+the case of an error, -1.
 
 It is legal to intermix calls to B<gzread> and B<gzreadline>.
 
@@ -688,9 +694,10 @@ At this time B<gzreadline> ignores the variable C<$/>
 (C<$INPUT_RECORD_SEPARATOR> or C<$RS> when C<English> is in use). The
 end of a line is denoted by the C character C<'\n'>.
 
-=item B<$status = $gz-E<gt>gzwrite($buffer) ;>
+=item B<$byteswritten = $gz-E<gt>gzwrite($buffer) ;>
 
-Writes the contents of B<$buffer> to the compressed file.
+Writes the contents of B<$buffer> to the compressed file. Returns the
+number of bytes actually written, or 0 on error.
 
 =item B<$status = $gz-E<gt>gzflush($flush) ;>
 
@@ -841,8 +848,8 @@ of I<Compress::Zlib>.
 =head1 AUTHOR
 
 The I<Compress::Zlib> module was written by Paul Marquess,
-F<pmarquess@bfsec.bt.co.uk>. The latest copy of the module can be found
-on CPAN in F<modules/by-module/Compress/Compress-Zlib-x.x.tar.gz>.
+F<Paul.Marquess@btinternet.com>. The latest copy of the module can be
+found on CPAN in F<modules/by-module/Compress/Compress-Zlib-x.x.tar.gz>.
 
 The I<zlib> compression library was written by Jean-loup Gailly
 F<gzip@prep.ai.mit.edu> and Mark Adler F<madler@alumni.caltech.edu>.
@@ -980,3 +987,23 @@ A number of fixes to the test suite and the example scripts to allow
 them to work under win32. All courtesy of Gurusamy Sarathy.
 
 =back
+
+=head2 1.02 10 Jan 1998
+
+=over 5
+
+=item 1.
+
+The return codes for gzread, gzreadline and gzwrite were documented
+incorrectly as returning a status code.
+
+=item 2.
+
+The test harness was missing a "gzclose". This caused problem showed up
+on an amiga. Thanks to Erik van Roode for reporting this one.
+
+=item 3.
+
+Patched zlib.t for OS/2. Thanks to Ilya Zakharevich for the patch.
+
+=back
